@@ -7,6 +7,10 @@ AIS.py - A Python interface for the Swisscom All-in Signing Service.
 
 """
 
+from typing import TYPE_CHECKING
+if TYPE_CHECKING:
+    from requests import Response
+
 
 class AISError(Exception):
     """Generic AIS Error."""
@@ -24,6 +28,18 @@ class AuthenticationFailed(AISError):
     pass
 
 
+class SignatureTooLarge(AISError):
+    """The signature received from AIS is too large to store.
+
+    This means the PDF needs to be created with a larger value
+    for sig_size to store the signature.
+    """
+
+    def __init__(self, signature_size: int):
+        self.signature_size = signature_size
+        super().__init__(f'{signature_size} bytes')
+
+
 class UnknownAISError(AISError):
     """Unknown AIS Error."""
 
@@ -36,7 +52,7 @@ minor_to_exception = {
 }
 
 
-def error_for(response):
+def error_for(response: 'Response') -> Exception:
     """Return the correct error for a response."""
     result = response.json()['SignResponse']['Result']
 
